# SCIentific ToolBoX (scitbx)

Author: Dr. Songyan Zhu University of Edinburgh
Contact: Songyan.Zhu@ed.ac.uk
Website: https://sites.google.com/view/uflux

A Python module to simplify many tedious work for scientific programming, e.g., auto-import libraries including numpy, pandas, etc and set up matplotlib canvas.